import ReactDOM from 'react-dom';
import { scaleBand, scaleLinear, format,nest,quantile,max,min, Math,abs } from 'd3';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Box } from './boxRect';
import { MedLine } from './medianLine';
import { CenterLine } from './centerLine';
import { UpLine } from './upperLine';
import { BottomLine } from './bottomLine';

const width = 960;
const height = 500;
const margin = { top: 20, right: 30, bottom: 65, left: 90 };
const boxwidth=60;
const boxOffSet=20;

const App = () => {
  const data = useData();

  if (!data) {
    return <pre>Loading...</pre>;
  }
  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;
  const siFormat = format('.2s');
  const xAxisTickFormat = tickValue => siFormat(tickValue).replace('G', 'B');
 	const filteredData = data.filter(d=>d.new_cases>=5500)

  var sumstatcontry = nest() 
    .key(function(d) { return d.location;})
    .rollup(function(d) {
      var arr=d.map(function(g){ return g.new_cases;}).sort()
      var keysSorted = Object.keys(arr).sort(function(a,b){return arr[a]-arr[b]}).map(key => arr[key])
      
      var q1=quantile(keysSorted,.25);
      var q3=quantile(keysSorted,.75);
      var median=quantile(keysSorted,.5);
      var interQuantileRange = (q3 - q1)
      var min_arr=  q1 - 1.5 * interQuantileRange
      var max_arr = q3 + 1.5 * interQuantileRange
      return({arr: arr, keysSorted: keysSorted, q1: q1, median: median, q3: q3, min: min_arr, max: max_arr})
    })
    .entries(filteredData)
    
   console.log(sumstatcontry);
  
   const yScale = scaleLinear()
    .domain([35000,-5000])
    .range([0, innerHeight]);

   const xScale = scaleBand()
    .range([ 0, innerWidth ])
   	.domain(sumstatcontry.map(d => d.key))
    .paddingInner(1)
    .paddingOuter(.2)

   
  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        <CenterLine
          data={sumstatcontry}
          xScale={xScale}
          yScale={yScale}
          boxwidth={boxwidth}
  				boxOffSet={boxOffSet}
        />
        <AxisLeft 
         yScale={yScale}
         innerWidth={innerWidth}
         tickFormat={xAxisTickFormat} 
      />
       <AxisBottom xScale={xScale} />
         <Box
          data={sumstatcontry}
          xScale={xScale}
          yScale={yScale}
  				boxwidth={boxwidth}
          tooltipFormat ={xAxisTickFormat}
        />
         <MedLine
          data={sumstatcontry}
          xScale={xScale}
          yScale={yScale}
  				boxwidth={boxwidth}
          boxOffSet={boxOffSet}
        />
 			<UpLine
           data={sumstatcontry}
          xScale={xScale}
          yScale={yScale}
  				boxwidth={boxwidth}
          boxOffSet={boxOffSet}
        />
        <BottomLine
           data={sumstatcontry}
          xScale={xScale}
          yScale={yScale}
  				boxwidth={boxwidth}
          boxOffSet={boxOffSet}
        />
       
        
     </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
